Inspired by alsi(https://github.com/trizen/alsi) which was written by (Trizen <echo dHJpemVueEBnbWFpbC5jb20K | base64 -d>)

ASCII artists in no particular order:
- Brett Bohnenkamper <kittykatt@silverirc.com>

Unknown artists, but other projects i used ASCII art from:
- screenfetch
- alsi

If i have missed crediting anyone please drop me an email.
